.. _vtksuite:

vtksuite.py
===========

This Python module contains one routine to convert from exadata to vtk data
structure.

.. warning::

   The module was a work in progress but is not in use anymore; we left it here
   for reference and possible future work.

-------------------------------------------------------------------------------

.. _vtksuite-contents:

Contents of vtksuite.py
-----------------------

.. automodule:: pymech.vtksuite
